{% load aasrp %}

<script
    src="{% aasrp_static 'aasrp/javascript/my-srp-requests.min.js' %}"
    integrity="sha512-HAmMdsguzaj4WiEQFNjvu6ykL70u/Tucj8aggl5grtLcSHNq8+Qcqi+oAhR02DI6WI04WfsFGVsIZsiPiHbohQ=="
    crossorigin="anonymous"
></script>
