{% load aasrp %}

<script
    src="{% aasrp_static 'aasrp/javascript/view-requests.min.js' %}"
    integrity="sha512-OX093crku4t8qUaI+nb6M29X6XPXNcikn/yZcjYEGq0VeP4f862u3uynXwky/MkFKOHBucuaPLDjcCU7RGhrKQ=="
    crossorigin="anonymous"
></script>
