{% load aasrp %}

<script
    src="{% aasrp_static 'aasrp/javascript/aa-srp.min.js' %}"
    integrity="sha512-SKL5pQAdZ1elLpwQNAi7E/kiO9txWBFPyYzCuClBx4psUpPwezz0LviMO8VEO09m0C7/q1KWLZPxXNJA/Igwxg=="
    crossorigin="anonymous"
></script>
