{% load aasrp %}

<script
    src="{% aasrp_static 'aasrp/javascript/srp-links.min.js' %}"
    integrity="sha512-qIB1r3Oqer36+Ujp4Y/cihZVpUf3mAEYerpQ2UqIjVkLpPMHAqoSOrf+wGq22isAKTjfSK4+9GWJlHbLnViaTw=="
    crossorigin="anonymous"
></script>
